diff sat/plugins/plugin_xep_0384.py @ 4051:c23cad65ae99

core: renamed `messageReceived` trigger to `message_received`
author Goffi <goffi@goffi.org>
date Mon, 29 May 2023 13:32:08 +0200
parents 524856bd7b19
children
line wrap: on
line diff
--- a/sat/plugins/plugin_xep_0384.py	Mon May 15 17:19:54 2023 +0200
+++ b/sat/plugins/plugin_xep_0384.py	Mon May 29 13:32:08 2023 +0200
@@ -1578,9 +1578,9 @@
 
         # These triggers are used by oldmemo, which doesn't do SCE and only applies to
         # messages. Temporarily, until a more fitting trigger for SCE-based encryption is
         # added, the messageReceived trigger is also used for twomemo.
         sat.trigger.add(
-            "messageReceived",
+            "message_received",
             self._message_received_trigger,
             priority=100050
         )
@@ -1578,9 +1578,9 @@
         # These triggers are used by oldmemo, which doesn't do SCE and only applies to
         # messages. Temporarily, until a more fitting trigger for SCE-based encryption is
-        # added, the messageReceived trigger is also used for twomemo.
+        # added, the message_received trigger is also used for twomemo.
         sat.trigger.add(